==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/MatchConditionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.MatchConditionArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.WebApplicationFirewallOperator
import com.pulumi.azurenative.network.kotlin.enums.WebApplicationFirewallTransform
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Define match conditions.
 * @property matchValues Match value.
 * @property matchVariables List of match variables.
 * @property negationConditon Whether this is negate condition or not.
 * @property operator The operator to be matched.
 * @property transforms List of transforms.
 */
public data class MatchConditionArgs(
    public val matchValues: Output<List<String>>,
    public val matchVariables: Output<List<MatchVariableArgs>>,
    public val negationConditon: Output<Boolean>? = null,
    public val `operator`: Output<Either<String, WebApplicationFirewallOperator>>,
    public val transforms: Output<List<Either<String, WebApplicationFirewallTransform>>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.MatchConditionArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.MatchConditionArgs =
        com.pulumi.azurenative.network.inputs.MatchConditionArgs.builder()
            .matchValues(matchValues.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .matchVariables(
                matchVariables.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .negationConditon(negationConditon?.applyValue({ args0 -> args0 }))
            .`operator`(
                `operator`.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .transforms(
                transforms?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform(
                            { args0 -> args0 },
                            { args0 -> args0.let({ args0 -> args0.toJava() }) },
                        )
                    })
                }),
            ).build()
}

/**
 * Builder for [MatchConditionArgs].
 */
@PulumiTagMarker
public class MatchConditionArgsBuilder internal constructor() {
    private var matchValues: Output<List<String>>? = null

    private var matchVariables: Output<List<MatchVariableArgs>>? = null

    private var negationConditon: Output<Boolean>? = null

    private var `operator`: Output<Either<String, WebApplicationFirewallOperator>>? = null

    private var transforms: Output<List<Either<String, WebApplicationFirewallTransform>>>? = null

    /**
     * @param value Match value.
     */
    @JvmName("miqcprkbsgjxnchm")
    public suspend fun matchValues(`value`: Output<List<String>>) {
        this.matchValues = value
    }

    @JvmName("bokpkiomcavuybsd")
    public suspend fun matchValues(vararg values: Output<String>) {
        this.matchValues = Output.all(values.asList())
    }

    /**
     * @param values Match value.
     */
    @JvmName("boypslbcdplqexql")
    public suspend fun matchValues(values: List<Output<String>>) {
        this.matchValues = Output.all(values)
    }

    /**
     * @param value List of match variables.
     */
    @JvmName("nfdtklblsnntxmyn")
    public suspend fun matchVariables(`value`: Output<List<MatchVariableArgs>>) {
        this.matchVariables = value
    }

    @JvmName("cgiyooowditrxnmd")
    public suspend fun matchVariables(vararg values: Output<MatchVariableArgs>) {
        this.matchVariables = Output.all(values.asList())
    }

    /**
     * @param values List of match variables.
     */
    @JvmName("babrqibdbdfgcgkx")
    public suspend fun matchVariables(values: List<Output<MatchVariableArgs>>) {
        this.matchVariables = Output.all(values)
    }

    /**
     * @param value Whether this is negate condition or not.
     */
    @JvmName("frgtieqtyjktseod")
    public suspend fun negationConditon(`value`: Output<Boolean>) {
        this.negationConditon = value
    }

    /**
     * @param value The operator to be matched.
     */
    @JvmName("koyyppjpfkygyaul")
    public suspend fun `operator`(`value`: Output<Either<String, WebApplicationFirewallOperator>>) {
        this.`operator` = value
    }

    /**
     * @param value List of transforms.
     */
    @JvmName("oyuyexgvmjhmtbyf")
    public suspend
    fun transforms(`value`: Output<List<Either<String, WebApplicationFirewallTransform>>>) {
        this.transforms = value
    }

    @JvmName("knetjhpmowwkimbr")
    public suspend fun transforms(
        vararg
        values: Output<Either<String, WebApplicationFirewallTransform>>,
    ) {
        this.transforms = Output.all(values.asList())
    }

    /**
     * @param values List of transforms.
     */
    @JvmName("ktkvgqhcenjkftxj")
    public suspend
    fun transforms(values: List<Output<Either<String, WebApplicationFirewallTransform>>>) {
        this.transforms = Output.all(values)
    }

    /**
     * @param value Match value.
     */
    @JvmName("cqegucwpuqeancle")
    public suspend fun matchValues(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.matchValues = mapped
    }

    /**
     * @param values Match value.
     */
    @JvmName("jiltbcnpaxefhwnw")
    public suspend fun matchValues(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.matchValues = mapped
    }

    /**
     * @param value List of match variables.
     */
    @JvmName("wbliencfhlnvetmf")
    public suspend fun matchVariables(`value`: List<MatchVariableArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.matchVariables = mapped
    }

    /**
     * @param argument List of match variables.
     */
    @JvmName("jsocaqblibqrsndq")
    public suspend fun matchVariables(argument: List<suspend MatchVariableArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            MatchVariableArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.matchVariables = mapped
    }

    /**
     * @param argument List of match variables.
     */
    @JvmName("ukteqgokexkxaayk")
    public suspend fun matchVariables(vararg argument: suspend MatchVariableArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            MatchVariableArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.matchVariables = mapped
    }

    /**
     * @param argument List of match variables.
     */
    @JvmName("udyiiujdrimgxmay")
    public suspend fun matchVariables(argument: suspend MatchVariableArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(MatchVariableArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.matchVariables = mapped
    }

    /**
     * @param values List of match variables.
     */
    @JvmName("jmrqdxddgrehrhht")
    public suspend fun matchVariables(vararg values: MatchVariableArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.matchVariables = mapped
    }

    /**
     * @param value Whether this is negate condition or not.
     */
    @JvmName("jvilpklqshixeywt")
    public suspend fun negationConditon(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.negationConditon = mapped
    }

    /**
     * @param value The operator to be matched.
     */
    @JvmName("pakrdanxdjihfjjl")
    public suspend fun `operator`(`value`: Either<String, WebApplicationFirewallOperator>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`operator` = mapped
    }

    /**
     * @param value The operator to be matched.
     */
    @JvmName("tkmfcdjnpssxqinj")
    public fun `operator`(`value`: String) {
        val toBeMapped = Either.ofLeft<String, WebApplicationFirewallOperator>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`operator` = mapped
    }

    /**
     * @param value The operator to be matched.
     */
    @JvmName("hhgfanntokgbomkd")
    public fun `operator`(`value`: WebApplicationFirewallOperator) {
        val toBeMapped = Either.ofRight<String, WebApplicationFirewallOperator>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`operator` = mapped
    }

    /**
     * @param value List of transforms.
     */
    @JvmName("trejpotbtjammrct")
    public suspend fun transforms(`value`: List<Either<String, WebApplicationFirewallTransform>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.transforms = mapped
    }

    /**
     * @param values List of transforms.
     */
    @JvmName("ymibpwubbdlkmtky")
    public suspend fun transforms(vararg values: Either<String, WebApplicationFirewallTransform>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.transforms = mapped
    }

    internal fun build(): MatchConditionArgs = MatchConditionArgs(
        matchValues = matchValues ?: throw PulumiNullFieldException("matchValues"),
        matchVariables = matchVariables ?: throw PulumiNullFieldException("matchVariables"),
        negationConditon = negationConditon,
        `operator` = `operator` ?: throw PulumiNullFieldException("operator"),
        transforms = transforms,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/MatchConditionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.MatchConditionArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.WebApplicationFirewallOperator
import com.pulumi.azurenative.network.kotlin.enums.WebApplicationFirewallTransform
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Define match conditions.
 * @property matchValues Match value.
 * @property matchVariables List of match variables.
 * @property negationConditon Whether this is negate condition or not.
 * @property operator The operator to be matched.
 * @property transforms List of transforms.
 */
public data class MatchConditionArgs(
    public val matchValues: Output<List<String>>,
    public val matchVariables: Output<List<MatchVariableArgs>>,
    public val negationConditon: Output<Boolean>? = null,
    public val `operator`: Output<Either<String, WebApplicationFirewallOperator>>,
    public val transforms: Output<List<Either<String, WebApplicationFirewallTransform>>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.MatchConditionArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.MatchConditionArgs =
        com.pulumi.azurenative.network.inputs.MatchConditionArgs.builder()
            .matchValues(matchValues.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .matchVariables(
                matchVariables.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .negationConditon(negationConditon?.applyValue({ args0 -> args0 }))
            .`operator`(
                `operator`.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .transforms(
                transforms?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform(
                            { args0 -> args0 },
                            { args0 -> args0.let({ args0 -> args0.toJava() }) },
                        )
                    })
                }),
            ).build()
}

/**
 * Builder for [MatchConditionArgs].
 */
@PulumiTagMarker
public class MatchConditionArgsBuilder internal constructor() {
    private var matchValues: Output<List<String>>? = null

    private var matchVariables: Output<List<MatchVariableArgs>>? = null

    private var negationConditon: Output<Boolean>? = null

    private var `operator`: Output<Either<String, WebApplicationFirewallOperator>>? = null

    private var transforms: Output<List<Either<String, WebApplicationFirewallTransform>>>? = null

    /**
     * @param value Match value.
     */
    @JvmName("fyldqytqpeebdaly")
    public suspend fun matchValues(`value`: Output<List<String>>) {
        this.matchValues = value
    }

    @JvmName("urnhyboncbltqagl")
    public suspend fun matchValues(vararg values: Output<String>) {
        this.matchValues = Output.all(values.asList())
    }

    /**
     * @param values Match value.
     */
    @JvmName("pulepdjmmeuwgfqs")
    public suspend fun matchValues(values: List<Output<String>>) {
        this.matchValues = Output.all(values)
    }

    /**
     * @param value List of match variables.
     */
    @JvmName("nwqlfepxiqpbxajv")
    public suspend fun matchVariables(`value`: Output<List<MatchVariableArgs>>) {
        this.matchVariables = value
    }

    @JvmName("nrejwpddfwjdtout")
    public suspend fun matchVariables(vararg values: Output<MatchVariableArgs>) {
        this.matchVariables = Output.all(values.asList())
    }

    /**
     * @param values List of match variables.
     */
    @JvmName("uaqesymmjqqbooah")
    public suspend fun matchVariables(values: List<Output<MatchVariableArgs>>) {
        this.matchVariables = Output.all(values)
    }

    /**
     * @param value Whether this is negate condition or not.
     */
    @JvmName("kaysbqarcpsvffmw")
    public suspend fun negationConditon(`value`: Output<Boolean>) {
        this.negationConditon = value
    }

    /**
     * @param value The operator to be matched.
     */
    @JvmName("pipyjishpbfglvhg")
    public suspend fun `operator`(`value`: Output<Either<String, WebApplicationFirewallOperator>>) {
        this.`operator` = value
    }

    /**
     * @param value List of transforms.
     */
    @JvmName("ggsdgdnvqeoviumg")
    public suspend
    fun transforms(`value`: Output<List<Either<String, WebApplicationFirewallTransform>>>) {
        this.transforms = value
    }

    @JvmName("cadxryivmudkqgjd")
    public suspend fun transforms(
        vararg
        values: Output<Either<String, WebApplicationFirewallTransform>>,
    ) {
        this.transforms = Output.all(values.asList())
    }

    /**
     * @param values List of transforms.
     */
    @JvmName("rfgahrsdnbebufdm")
    public suspend
    fun transforms(values: List<Output<Either<String, WebApplicationFirewallTransform>>>) {
        this.transforms = Output.all(values)
    }

    /**
     * @param value Match value.
     */
    @JvmName("ioahghhgvalcynvc")
    public suspend fun matchValues(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.matchValues = mapped
    }

    /**
     * @param values Match value.
     */
    @JvmName("shpbbngqghrlvwbx")
    public suspend fun matchValues(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.matchValues = mapped
    }

    /**
     * @param value List of match variables.
     */
    @JvmName("ltmbulfencybrgtt")
    public suspend fun matchVariables(`value`: List<MatchVariableArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.matchVariables = mapped
    }

    /**
     * @param argument List of match variables.
     */
    @JvmName("mllnnkqbttgfbwmo")
    public suspend fun matchVariables(argument: List<suspend MatchVariableArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            MatchVariableArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.matchVariables = mapped
    }

    /**
     * @param argument List of match variables.
     */
    @JvmName("xisptuhyowhyitci")
    public suspend fun matchVariables(vararg argument: suspend MatchVariableArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            MatchVariableArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.matchVariables = mapped
    }

    /**
     * @param argument List of match variables.
     */
    @JvmName("auismuwuaafpoeqj")
    public suspend fun matchVariables(argument: suspend MatchVariableArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(MatchVariableArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.matchVariables = mapped
    }

    /**
     * @param values List of match variables.
     */
    @JvmName("ibhwxajsmnnxnmul")
    public suspend fun matchVariables(vararg values: MatchVariableArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.matchVariables = mapped
    }

    /**
     * @param value Whether this is negate condition or not.
     */
    @JvmName("ouddlivtwbgxlivo")
    public suspend fun negationConditon(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.negationConditon = mapped
    }

    /**
     * @param value The operator to be matched.
     */
    @JvmName("uqayaxvngfwpquvt")
    public suspend fun `operator`(`value`: Either<String, WebApplicationFirewallOperator>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`operator` = mapped
    }

    /**
     * @param value The operator to be matched.
     */
    @JvmName("rmqoxtyaqgminjga")
    public fun `operator`(`value`: String) {
        val toBeMapped = Either.ofLeft<String, WebApplicationFirewallOperator>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`operator` = mapped
    }

    /**
     * @param value The operator to be matched.
     */
    @JvmName("ovbmsteygatoxori")
    public fun `operator`(`value`: WebApplicationFirewallOperator) {
        val toBeMapped = Either.ofRight<String, WebApplicationFirewallOperator>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`operator` = mapped
    }

    /**
     * @param value List of transforms.
     */
    @JvmName("gehripviyfuodxhy")
    public suspend fun transforms(`value`: List<Either<String, WebApplicationFirewallTransform>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.transforms = mapped
    }

    /**
     * @param values List of transforms.
     */
    @JvmName("hxkwqjobtdiggduv")
    public suspend fun transforms(vararg values: Either<String, WebApplicationFirewallTransform>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.transforms = mapped
    }

    internal fun build(): MatchConditionArgs = MatchConditionArgs(
        matchValues = matchValues ?: throw PulumiNullFieldException("matchValues"),
        matchVariables = matchVariables ?: throw PulumiNullFieldException("matchVariables"),
        negationConditon = negationConditon,
        `operator` = `operator` ?: throw PulumiNullFieldException("operator"),
        transforms = transforms,
    )
}
